# *cabaret*

**cabaret** is a Python package to simulate astronomical images using the [Gaia catalog](https://en.wikipedia.org/wiki/Gaia_catalogues) of stars.  
It allows you to generate synthetic images, configure observatory components, and customize simulations for research or educational purposes.

---

## Table of content
```{toctree}
:maxdepth: 1
:caption: Get started

installation
motivation
notebooks/quickstart.ipynb
citation
```

```{toctree}
:maxdepth: 1
:caption: Tutorials

notebooks/configuring_an_observatory.ipynb
```

```{toctree}
:maxdepth: 1
:caption: Reference

cabaret
```
